@@ -122,10 +122,10 @@ arma::mat try_inv(arma::mat M,int nvar)
   try
   {
     std::ostream nullstream(0);
-    arma::set_stream_err2(nullstream);
+    arma::set_cerr_stream(nullstream);
     //Minv = pinv(M);
     //M = try_clip(M,nvar,1);
-    Minv = inv(M,"std");    
+    Minv = inv(M); //Minv = inv(M,"std");
     return Minv;
   }
   catch(...)
@@ -141,9 +141,9 @@ arma::mat try_solve(arma::mat M,arma::mat V)
   try
   {
     std::ostream nullstream(0);
-    arma::set_stream_err2(nullstream);
+    arma::set_cerr_stream(nullstream);
     //M = try_clip(M,nvar,1);
-    Msolve = solve(M,V,"std");
+    Msolve = solve(M,V); //Msolve = solve(M,V,"std");
     //Msolve = pinv(M)*V;
     return Msolve;
   }
@@ -176,7 +176,7 @@ double logdet(arma::mat A)
   try
   {
     std::ostream nullstream(0);
-    arma::set_stream_err2(nullstream);
+    arma::set_cerr_stream(nullstream);
     log_det(val,sign,A);
     return val;
   }
